/*
 * Copyright  2002  Networks Associates Technology, Inc.
 * All rights reserved.
 *
 * myexec.c
 * This program executes "id" as user "joe".  Its simply a small test
 * program for priv_execve.
 *
 * $Id: myexec.c,v 1.5 2002/10/30 20:49:39 dougk Exp $
 */

#include "../config.h"

#define ID_PATH "/usr/bin/id"

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "privman.h"

extern char **environ;

int main(void)
{
    char *argv[2] = { "id", 0 };
    priv_init("myexec");

    priv_execve(ID_PATH, argv, environ, "joe", 0);

    perror("priv_execve");

    return -1;
}
